@@ -21,11 +21,8 @@ from example.views import PrivateView, PublicView
 from slxauth.views import LoginView, CallbackView
 
 urlpatterns = [
-    url(r'^admin/', admin.site.urls),
-
-    url(r'^$', PublicView.as_view(), name='public'),
-    url(r'^private/$', PrivateView.as_view(), name='private'),
-
-    url(r'^accounts/', include('slxauth.urls', namespace='slxauth')),
-
+    url(r"^admin/", admin.site.urls),
+    url(r"^$", PublicView.as_view(), name="public"),
+    url(r"^private/$", PrivateView.as_view(), name="private"),
+    url(r"^accounts/", include("slxauth.urls", namespace="slxauth")),
 ]
